@@ -107,15 +107,9 @@ pid_t anjuta_util_execute_shell (const gchar *dir, const gchar *command);
 
 gchar* anjuta_util_escape_quotes(const gchar* str);
 
-/* FIXME: Instead of this, check for forkpty implementation in configure.in
- * Sun specific implementations
- *
- */
-#ifdef sun
-#include <grp.h>
-int forkpty(int *amaster, char *name, struct termios *termp, struct winsize *winp);
-int alphasort (const struct dirent **a, const struct dirent **b);
-#endif /* sun */
+gboolean anjuta_util_path_has_extension (const gchar *path, const gchar *ext);
+
+gchar* anjuta_util_get_uri_mime_type (const gchar *uri);
 
 /* Temporarily copied here */
 
