@@ -373,13 +373,13 @@ atp_output_context_print (ATPOutputContext *this, const gchar* text)
 		if (this->created == FALSE)
 		{
 			IAnjutaMessageManager *man;
-			gchar* title;
+			gchar* title  = this->execution->name;
 
 			man = anjuta_shell_get_interface (this->execution->plugin->shell,
 											  IAnjutaMessageManager, NULL);
 			if (this->view == NULL)
 			{
-				this->view = ianjuta_message_manager_add_view (man, "",
+				this->view = ianjuta_message_manager_add_view (man, title,
 															   ICON_FILE,
 															   NULL);
 				g_signal_connect (G_OBJECT (this->view), "buffer_flushed",
@@ -928,7 +928,6 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 	gchar* cmd;
 	gchar* input;
 	gchar* val = NULL;
-	guint len;
 
 	plugin = atp_user_tool_get_plugin (this);
 	variable = atp_plugin_get_variable (plugin);
@@ -966,8 +965,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 			ed = docman == NULL ? NULL : ianjuta_document_manager_get_current_editor (docman, NULL);
 			if (ed != NULL)
 			{
-				len = ianjuta_editor_get_length (ed, NULL);
-				input = ianjuta_editor_get_text (ed, 0, len, NULL);
+				input = ianjuta_editor_get_text (ed, 0, -1, NULL);
 			}
 			break;
 		case ATP_TIN_SELECTION:
