@@ -34,10 +34,12 @@
 #include <gdl/gdl-dock.h>
 #include <gdl/gdl-dock-bar.h>
 
+#include <bonobo/bonobo-dock-item.h>
+
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
-#include <libanjuta/plugins.h>
+#include <libanjuta/anjuta-plugin-manager.h>
 #include <libanjuta/anjuta-debug.h>
 
 #include "anjuta-app.h"
@@ -49,6 +51,11 @@
 #define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta.glade"
 #define ICON_FILE "preferences-general.png"
 
+#define DOCK_PH_LEFT    "ph_left"
+#define DOCK_PH_RIGHT   "ph_right"
+#define DOCK_PH_TOP     "ph_top"
+#define DOCK_PH_BOTTOM  "ph_bottom"
+
 static void anjuta_app_layout_load (AnjutaApp *app,
 									const gchar *layout_filename,
 									const gchar *name);
@@ -133,26 +140,44 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 	BonoboDockItem *dock_item;
 	const gchar *name;
 	gint band;
+	gint position;
+	gint offset;
+
 	
 	name = gtk_widget_get_name (widget);
 	app = g_object_get_data (G_OBJECT(widget), "app");
 	dock_item = g_object_get_data (G_OBJECT(widget), "dock_item");
 	band = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "band"));
+	position = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "position"));
+	offset = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(widget), "offset"));
+
 	
 	if (gtk_check_menu_item_get_active (menuitem))
 	{
 		if (!dock_item)
 		{
+			static gint count;
+			gchar *unique_name = g_strdup_printf ("%s-%d", name, count);
+			
+			/* gnome_app_add_docked() does not allow adding a widget using
+			 * a previously used name (even if the previous widget has
+			 * has be destroyed. Hence a unique_name is used by using a 
+			 * static counter */
+			DEBUG_PRINT ("Adding dock item %s band %d, offset %d, position %d", unique_name,
+						 band, offset, position);
+			
 			/* Widget not yet added to the dock. Add it */
 			gnome_app_add_docked (GNOME_APP (app), widget,
-								  name,
+								  unique_name,
 								  BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL |
 								  BONOBO_DOCK_ITEM_BEH_NEVER_FLOATING,
-								  BONOBO_DOCK_TOP, band, 0, 0);
-		
+								  BONOBO_DOCK_TOP, band, position, offset);
+									   									   
 			dock_item = gnome_app_get_dock_item_by_name (GNOME_APP (app),
-														 name);
+														 unique_name);
+			g_object_set_data_full (G_OBJECT(dock_item), "unique_name", unique_name, g_free);
 			g_object_set_data (G_OBJECT(widget), "dock_item", dock_item);
+			count++;
 		}
 		gtk_widget_show (GTK_WIDGET (dock_item));
 		gtk_widget_show (GTK_BIN (dock_item)->child);
@@ -164,6 +189,14 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 	}
 }
 
+static void
+on_merge_widget_destroy (GtkWidget *merge_widget, GtkWidget *menuitem)
+{
+	toolbars = g_list_remove (toolbars, merge_widget);
+	DEBUG_PRINT ("Destroying menuitem for toolbar widget");
+	gtk_widget_destroy (menuitem);
+}
+
 static void
 on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 					 GtkWidget *ui_container)
@@ -179,29 +212,42 @@ on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 	{
 		static gint count = 0;
 		const gchar *toolbarname;
-		gchar* key;
+		gchar* visible_key;
+		gchar* band_key;
+		gchar* position_key;
+		gchar* offset_key;		
 		AnjutaPreferences *pr;
 		GtkWidget *menuitem;
+		gint band;
+		gint position;
+		gint offset;
+		pr = ANJUTA_PREFERENCES (ANJUTA_APP(ui_container)->preferences);
 		
-		/*
-		gtk_toolbar_set_icon_size (GTK_TOOLBAR (widget),
-								   GTK_ICON_SIZE_SMALL_TOOLBAR);
-		*/
+		/* Showing the arrows seem to break anything completly! */
 		gtk_toolbar_set_show_arrow (GTK_TOOLBAR (widget), FALSE);
 		
-		/* FIXME: This is probably not HIG-friendly. But the text/both
-		 * toolbar styles in anjuta is horible. We need to fix that first.
-		 */
-		gtk_toolbar_set_style (GTK_TOOLBAR (widget), GTK_TOOLBAR_BOTH_HORIZ);
-		
-		toolbarname = gtk_widget_get_name (widget);
-		
-		DEBUG_PRINT ("Adding toolbar: %s", toolbarname);
-		
 		gtk_widget_show (widget);
 		g_object_set_data (G_OBJECT (widget), "app", ui_container);
+		
+		/* Load toolbar position */
+		toolbarname = gtk_widget_get_name (widget);
+		band_key = g_strconcat (toolbarname, ".band", NULL);
+		position_key = g_strconcat (toolbarname, ".position", NULL);
+		offset_key = g_strconcat (toolbarname, ".offset", NULL);		
+		band = anjuta_preferences_get_int_with_default(pr, band_key, -1);
+		position = anjuta_preferences_get_int_with_default(pr, position_key, 0);
+		offset = anjuta_preferences_get_int_with_default(pr, offset_key, 0);		
+		/* Without these check you might see odd results */
+		if (band < 1)
+			band = count + 1;
+		g_object_set_data(G_OBJECT(widget), "position", GINT_TO_POINTER(position));
+		g_object_set_data(G_OBJECT(widget), "offset", GINT_TO_POINTER(offset));
 		g_object_set_data (G_OBJECT (widget), "band",
-						   GINT_TO_POINTER(count+1));
+						   GINT_TO_POINTER(band));
+		g_free(offset_key);
+		g_free(position_key);
+		g_free(band_key);
+		DEBUG_PRINT ("Adding toolbar: %s", toolbarname);
 		
 		if (!ANJUTA_APP (ui_container)->toolbars_menu)
 		{
@@ -215,18 +261,25 @@ on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 		gtk_widget_show (GTK_WIDGET (menuitem));
 		g_signal_connect (G_OBJECT (menuitem), "toggled",
 						  G_CALLBACK (on_toolbar_view_toggled), widget);
+		g_object_set_data(G_OBJECT(widget), "menuitem", menuitem);
+		
+		/* When the toolbar is destroyed make sure corresponding menuitem is
+		 * also destroyed */
+		g_signal_connect (widget, "destroy",
+						  G_CALLBACK (on_merge_widget_destroy),
+						  menuitem);
+		
 		toolbars = g_list_append(toolbars, widget);
 
 		/* Show/hide toolbar */
-		pr = ANJUTA_PREFERENCES (ANJUTA_APP(ui_container)->preferences);
-		key = g_strconcat (toolbarname, ".visible", NULL);
-		if (anjuta_preferences_get_int_with_default (pr, key,
+		visible_key = g_strconcat (toolbarname, ".visible", NULL);
+		if (anjuta_preferences_get_int_with_default (pr, visible_key,
 													 (count == 0)? 1:0))
 		{
 			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
 											TRUE);
 		}
-		g_free (key);
+		g_free (visible_key);
 		count ++;
 	}
 }
@@ -250,17 +303,42 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 		GtkWidget* dock_item = g_object_get_data (G_OBJECT(widget), "dock_item");;
 		const gchar* toolbarname = gtk_widget_get_name(widget);
 		AnjutaPreferences* pr = ANJUTA_PREFERENCES (app->preferences);
-		gboolean visible;
+				
 		if (dock_item)
 		{
+			gboolean visible;
 			gchar* key = g_strconcat (toolbarname, ".visible", NULL);
+			gchar* band_key = g_strconcat (toolbarname, ".band", NULL);
+			gchar* position_key = g_strconcat (toolbarname, ".position", NULL);
+			gchar* offset_key = g_strconcat (toolbarname, ".offset", NULL);
+			GnomeApp* gnome_app = GNOME_APP(app);
+			
+			/* Save visibility */
 			g_object_get(G_OBJECT(dock_item), "visible", &visible, NULL);
 			anjuta_preferences_set_int(pr, key, visible);
 			g_free(key);
+			
+			/* Save toolbar position */
+			if (gnome_app->dock != NULL)
+			{
+				guint band;
+				guint position;
+				guint offset;
+				BonoboDockPlacement placement;
+				gchar* unique_name = g_object_get_data(G_OBJECT(dock_item), "unique_name");
+				
+				BonoboDockItem* item = bonobo_dock_get_item_by_name(BONOBO_DOCK(gnome_app->dock), 
+																  unique_name, &placement, 
+																   &band, &position, &offset);
+				g_return_if_fail(item != NULL);
+			
+				anjuta_preferences_set_int(pr, band_key, band);
+				anjuta_preferences_set_int(pr, position_key, position);
+				anjuta_preferences_set_int(pr, offset_key, offset);
+			}
 		}
 		node = g_list_next(node);
 	}
-
 	
 	/* Save geometry */
 	state = gdk_window_get_state (GTK_WIDGET (app)->window);
@@ -340,7 +418,8 @@ static void
 anjuta_app_dispose (GObject *widget)
 {
 	AnjutaApp *app;
-
+	GList *tmp_list;
+	
 	g_return_if_fail (ANJUTA_IS_APP (widget));
 	
 	app = ANJUTA_APP (widget);
@@ -373,10 +452,30 @@ anjuta_app_dispose (GObject *widget)
 		app->values = NULL;
 	}
 	
+	/* We need to destroy to the toolbars now so that the
+	 * on_merge_widget_destroy() does not produce a error trying to destory
+	 * already destroyed menuitems which happen when the window is being
+	 * destroyed
+	 *
+	 * Make a tmp list because the handler removes items from 'toolbars' list.
+	 * FIXME: Why is 'toolbars' a global static variable?
+	 */
+	tmp_list = g_list_copy (toolbars);
+	g_list_foreach (tmp_list, (GFunc)gtk_widget_destroy, NULL);
+	g_list_free (tmp_list);
+	
 	if (app->layout_manager) {
 		g_object_unref (app->layout_manager);
 		app->layout_manager = NULL;
 	}
+	if (app->profile_manager) {
+		g_object_unref (G_OBJECT (app->profile_manager));
+		app->profile_manager = NULL;
+	}
+	if (app->plugin_manager) {
+		g_object_unref (G_OBJECT (app->plugin_manager));
+		app->plugin_manager = NULL;
+	}
 	if (app->status) {
 		g_object_unref (G_OBJECT (app->status));
 		app->status = NULL;
@@ -392,7 +491,7 @@ anjuta_app_finalize (GObject *widget)
 	g_return_if_fail (ANJUTA_IS_APP (widget));
 	
 	app = ANJUTA_APP (widget);
-
+	
 	gtk_widget_destroy (GTK_WIDGET (app->ui));
 	gtk_widget_destroy (GTK_WIDGET (app->preferences));
 	
@@ -409,9 +508,9 @@ anjuta_app_instance_init (AnjutaApp *app)
 	GtkWidget *dockbar;
 	GtkAccelGroup *accel_group;
 	GtkAction* action;
-	
+	GList *plugins_dirs = NULL;
 	GdkGeometry size_hints = {
-    	100, 100, 0, 0, 100, 100, 0, 0, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST  
+    	100, 100, 0, 0, 100, 100, 1, 1, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST
   	};
 	
 	DEBUG_PRINT ("Initializing Anjuta...");
@@ -444,30 +543,18 @@ anjuta_app_instance_init (AnjutaApp *app)
 					  G_CALLBACK (on_layout_dirty_notify), app);
 	g_signal_connect (app->layout_manager->master, "notify::locked",
 					  G_CALLBACK (on_layout_locked_notify), app);
-	
-	/* Create placeholders for default widget positions */
-	gdl_dock_placeholder_new ("ph_top", GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_TOP, FALSE);
-	gdl_dock_placeholder_new ("ph_bottom", GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_BOTTOM, FALSE);
-	gdl_dock_placeholder_new ("ph_left", GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_LEFT, FALSE);
-	gdl_dock_placeholder_new ("ph_right", GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_RIGHT, FALSE);
-	gdl_dock_placeholder_new ("ph_center", GDL_DOCK_OBJECT (app->dock),
-							  GDL_DOCK_CENTER, FALSE);
-							  
 	/* Status bar */
 	app->status = ANJUTA_STATUS (anjuta_status_new ());
+	anjuta_status_set_title_window (app->status, GTK_WIDGET (app));
 	gtk_widget_show (GTK_WIDGET (app->status));
 	gnome_app_set_statusbar (GNOME_APP (app), GTK_WIDGET (app->status));
 	g_object_ref (G_OBJECT (app->status));
-	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer*)&app->status);
+	g_object_add_weak_pointer (G_OBJECT (app->status), (gpointer)&app->status);
 	
 	/* Preferences */
 	app->preferences = ANJUTA_PREFERENCES (anjuta_preferences_new ());
 	g_object_add_weak_pointer (G_OBJECT (app->preferences),
-							   (gpointer*)&app->preferences);
+							   (gpointer)&app->preferences);
 	anjuta_status_add_widget (ANJUTA_STATUS (app->status),
 							  GTK_WIDGET (app->preferences));
 	/* UI engine */
@@ -481,35 +568,43 @@ anjuta_app_instance_init (AnjutaApp *app)
 	g_signal_connect (G_OBJECT (app->ui),
 					  "add_widget", G_CALLBACK (on_add_merge_widget),
 					  app);
-	g_object_add_weak_pointer (G_OBJECT (app->ui), (gpointer*)&app->ui);
+	g_object_add_weak_pointer (G_OBJECT (app->ui), (gpointer)&app->ui);
+	
+	/* Plugin Manager */
+	plugins_dirs = g_list_prepend (plugins_dirs, PACKAGE_PLUGIN_DIR);
+	app->plugin_manager = anjuta_plugin_manager_new (G_OBJECT (app),
+													 app->status,
+													 plugins_dirs);
+	app->profile_manager = anjuta_profile_manager_new (app->plugin_manager);
+	g_list_free (plugins_dirs);
 	
 	/* Register actions */
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupFile", _("File"),
 										menu_entries_file,
 										G_N_ELEMENTS (menu_entries_file),
-										GETTEXT_PACKAGE, app);
+										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupEdit", _("Edit"),
 										menu_entries_edit,
 										G_N_ELEMENTS (menu_entries_edit),
-										GETTEXT_PACKAGE, app);
+										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupView", _("View"),
 										menu_entries_view,
 										G_N_ELEMENTS (menu_entries_view),
-										GETTEXT_PACKAGE, app);
+										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_toggle_action_group_entries (app->ui, "ActionGroupToggleView",
 										_("Toggle View"),
 										menu_entries_toggle_view,
 										G_N_ELEMENTS (menu_entries_toggle_view),
-										GETTEXT_PACKAGE, app);
+										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupSettings",
 										_("Settings"),
 										menu_entries_settings,
 										G_N_ELEMENTS (menu_entries_settings),
-										GETTEXT_PACKAGE, app);
+										GETTEXT_PACKAGE, TRUE, app);
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupHelp", _("Help"),
 										menu_entries_help,
 										G_N_ELEMENTS (menu_entries_help),
-										GETTEXT_PACKAGE, app);
+										GETTEXT_PACKAGE, TRUE, app);
 
 	/* Merge UI */
 	merge_id = anjuta_ui_merge (app->ui, UI_FILE);
@@ -549,7 +644,7 @@ anjuta_app_instance_init (AnjutaApp *app)
 	/* Create preferences page */
 	gxml = glade_xml_new (GLADE_FILE, "anjuta_preferences_window", NULL);
 	anjuta_preferences_add_page (app->preferences, gxml,
-								 "General", ICON_FILE);
+								 "General", _("General"), ICON_FILE);
 	g_object_unref (gxml);
 	
 	/* Connect to session */
@@ -788,8 +883,8 @@ anjuta_app_remove_value (AnjutaShell *shell, const char *name, GError **error)
 	*/
 	
 	if (app->values && g_hash_table_lookup_extended (app->values, name, 
-													 (gpointer*)&key,
-													 (gpointer*)&value)) {
+													 (gpointer)&key,
+													 (gpointer)&value)) {
 		g_signal_emit_by_name (app, "value_removed", name);
 		g_hash_table_remove (app->values, name);
 	}
@@ -820,6 +915,10 @@ on_widget_remove (GtkWidget *container, GtkWidget *widget, AnjutaApp *app)
 	{
 		if (node->data == widget)
 		{
+			g_message("Removing toolbar");
+			GtkWidget* menuitem = GTK_WIDGET(g_object_get_data(G_OBJECT(widget), "menuitem"));
+			gtk_widget_hide(menuitem);
+			gtk_widget_destroy(menuitem);
 			toolbars = g_list_delete_link(toolbars, node);
 			break;
 		}
@@ -829,6 +928,8 @@ on_widget_remove (GtkWidget *container, GtkWidget *widget, AnjutaApp *app)
 	dock_item = g_object_get_data (G_OBJECT (widget), "dockitem");
 	if (dock_item)
 	{
+		gchar* unique_name = g_object_get_data(G_OBJECT(dock_item), "unique_name");
+		g_free(unique_name);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dock_item),
 					G_CALLBACK (on_widget_remove), app);
 		gdl_dock_item_unbind (GDL_DOCK_ITEM(dock_item));
@@ -878,8 +979,6 @@ anjuta_app_add_widget (AnjutaShell *shell,
 	AnjutaApp *app;
 	GtkWidget *item;
 	GtkCheckMenuItem* menuitem;
-	GdlDockPlaceholder* placeholder;
-	const gchar *placeholder_name;
 
 	g_return_if_fail (ANJUTA_IS_APP (shell));
 	g_return_if_fail (GTK_IS_WIDGET (widget));
@@ -910,27 +1009,8 @@ anjuta_app_add_widget (AnjutaShell *shell,
 		item = gdl_dock_item_new_with_stock (name, title, stock_id,
 											 GDL_DOCK_ITEM_BEH_NORMAL);
 	gtk_container_add (GTK_CONTAINER (item), widget);
-	
-	if (placement != GDL_DOCK_FLOATING)
-	{
-		switch (placement)
-		{
-			case GDL_DOCK_TOP: placeholder_name = "ph_top"; break;
-			case GDL_DOCK_BOTTOM: placeholder_name = "ph_bottom"; break;
-			case GDL_DOCK_LEFT: placeholder_name = "ph_left"; break;
-			case GDL_DOCK_RIGHT: placeholder_name = "ph_right"; break;
-			default: placeholder_name = "ph_center";
-		}
-		
-		placeholder = gdl_dock_get_placeholder_by_name (GDL_DOCK (app->dock), 
-														placeholder_name);
-		gtk_container_add (GTK_CONTAINER (placeholder), GTK_WIDGET (item));
-	}
-	else
-	{
-        gdl_dock_add_item (GDL_DOCK (app->dock),
-                           GDL_DOCK_ITEM (item), GDL_DOCK_FLOATING);
-	}
+    gdl_dock_add_item (GDL_DOCK (app->dock),
+                       GDL_DOCK_ITEM (item), placement);
 	gtk_widget_show_all (item);
 	
 	/* Add toggle button for the widget */
@@ -974,8 +1054,11 @@ anjuta_app_remove_widget (AnjutaShell *shell, GtkWidget *widget,
 	dock_item = g_object_get_data (G_OBJECT (widget), "dockitem");
 	g_return_if_fail (dock_item != NULL);
 	
-	/* Following unbind will remove the widget from hash */
-	gdl_dock_item_unbind (GDL_DOCK_ITEM (dock_item));
+	/* Remove the widget from container */
+	g_object_ref (widget);
+	/* It should call on_widget_remove() and clean up should happen */
+	gtk_container_remove (GTK_CONTAINER (dock_item), widget);
+	g_object_unref (widget);
 }
 
 static void 
@@ -983,7 +1066,7 @@ anjuta_app_present_widget (AnjutaShell *shell, GtkWidget *widget,
 						   GError **error)
 {
 	AnjutaApp *app;
-	GtkWidget *dock_item;
+	GdlDockItem *dock_item;
 	GtkWidget *parent;
 	
 	g_return_if_fail (ANJUTA_IS_APP (shell));
@@ -997,15 +1080,22 @@ anjuta_app_present_widget (AnjutaShell *shell, GtkWidget *widget,
 	g_return_if_fail (dock_item != NULL);
 	
 	/* Hack to present the dock item if it's in a notebook dock item */
-	parent = gtk_widget_get_parent (dock_item);
+	parent = gtk_widget_get_parent (GTK_WIDGET(dock_item) );
 	if (GTK_IS_NOTEBOOK (parent))
 	{
 		gint pagenum;
-		pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (parent), dock_item);
+		pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (parent), GTK_WIDGET (dock_item));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (parent), pagenum);
+	} 
+	else if (!GDL_DOCK_OBJECT_ATTACHED (dock_item)) 
+	{ 
+	    gdl_dock_item_show_item (GDL_DOCK_ITEM (dock_item));  
 	}
-	/* FIXME: If the item is hidden, show it */
+	
 	/* FIXME: If the item is floating, present the window */
+	/* FIXME: There is no way to detect if a widget was floating before it was
+	detached since it no longer has a parent there is no way to access the
+	floating property of the GdlDock structure.*/
 }
 
 static GObject*
@@ -1014,7 +1104,8 @@ anjuta_app_get_object  (AnjutaShell *shell, const char *iface_name,
 {
 	g_return_val_if_fail (ANJUTA_IS_APP (shell), NULL);
 	g_return_val_if_fail (iface_name != NULL, NULL);
-	return anjuta_plugins_get_plugin (shell, iface_name);
+	return anjuta_plugin_manager_get_plugin (ANJUTA_APP (shell)->plugin_manager,
+											 iface_name);
 }
 
 static AnjutaStatus*
@@ -1038,6 +1129,20 @@ anjuta_app_get_preferences  (AnjutaShell *shell, GError **error)
 	return ANJUTA_APP (shell)->preferences;
 }
 
+static AnjutaPluginManager *
+anjuta_app_get_plugin_manager  (AnjutaShell *shell, GError **error)
+{
+	g_return_val_if_fail (ANJUTA_IS_APP (shell), NULL);
+	return ANJUTA_APP (shell)->plugin_manager;
+}
+
+static AnjutaProfileManager *
+anjuta_app_get_profile_manager (AnjutaShell *shell, GError **error)
+{
+	g_return_val_if_fail (ANJUTA_IS_APP (shell), NULL);
+	return ANJUTA_APP (shell)->profile_manager;
+}
+
 static void
 anjuta_shell_iface_init (AnjutaShellIface *iface)
 {
@@ -1051,47 +1156,10 @@ anjuta_shell_iface_init (AnjutaShellIface *iface)
 	iface->get_status = anjuta_app_get_status;
 	iface->get_ui = anjuta_app_get_ui;
 	iface->get_preferences = anjuta_app_get_preferences;
+	iface->get_plugin_manager = anjuta_app_get_plugin_manager;
+	iface->get_profile_manager = anjuta_app_get_profile_manager;
 }
 
 ANJUTA_TYPE_BEGIN(AnjutaApp, anjuta_app, GNOME_TYPE_APP);
 ANJUTA_TYPE_ADD_INTERFACE(anjuta_shell, ANJUTA_TYPE_SHELL);
 ANJUTA_TYPE_END;
-
-#if 0 /* FIXME: Implement progress bar in AnjutaShell */
-gboolean
-anjuta_app_progress_init (AnjutaApp *app, gchar * description,
-						  gdouble full_value,
-						  GnomeAppProgressCancelFunc cancel_cb,
-						  gpointer data)
-{
-	if (app->in_progress)
-		return FALSE;
-	app->in_progress = TRUE;
-	app->progress_value = 0.0;
-	app->progress_full_value = full_value;
-	app->progress_cancel_cb = cancel_cb;
-	app->progress_key =
-		gnome_app_progress_timeout (GNOME_APP (app),
-					    description,
-					    100,
-					    on_anjuta_progress_cb,
-					    on_anjuta_progress_cancel, data);
-	return TRUE;
-}
-
-void
-anjuta_app_progress_set (AnjutaApp *app, gdouble value)
-{
-	if (app->in_progress)
-		app->progress_value = value / app->progress_full_value;
-}
-
-void
-anjuta_app_progress_done (AnjutaApp *app, gchar * end_mesg)
-{
-	if (app->in_progress)
-		gnome_app_progress_done (app->progress_key);
-	anjuta_status (end_mesg);
-	app->in_progress = FALSE;
-}
-#endif
